<?php

// PageIndex.class.php
//
// $Id: PageIndex.class.php 1424 2008-12-29 16:09:36Z tim $
//
// (c)2003-2004 Tim Jackson (tim@timj.co.uk)
//
// This library is free software; you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public
// License as published by the Free Software Foundation; either
// version 2.1 of the License, or (at your option) any later version.
//
// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.
// 
// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

// The default max number of pages which will be shown in a pageindex
define('PAGEINDEX_LIMIT_PAGES_DEFAULT',15);
// The default pages to skip if number of pages exceeds PAGEINDEX_LIMIT_PAGES_DEFAULT
define('PAGEINDEX_SKIP_PAGES_DEFAULT',10);

class PageIndex {
	
	var $Pages = 0;
	var $CurrentPage;
	var $URL;
	var $Separator=' ';
	var $LimitPages = PAGEINDEX_LIMIT_PAGES_DEFAULT;
	var $SkipPages = PAGEINDEX_SKIP_PAGES_DEFAULT;
	var $NextPrev=false; 
	var $Prev='&lt;&lt;';
	var $Next='&gt;&gt;';
	var $Header = "<div class='pageindex'>";
	var $Footer = "</div>";
	var $HideEndNextPrev = false;
	var $LinkCurrentPage = false;
	var $_Output = '';
	
	function PageIndex($Pages,$CurrentPage,$URL)
	{
		$this->Pages = $Pages;
		$this->CurrentPage = $CurrentPage;
		$this->URL = $URL;
		return true;
	}
	
	
	function generate() {
		if ($this->Pages > 1) {
			$this->_Output = $this->Header;
			
			// Print 'Prev'
			if ($this->NextPrev) {
				if ($this->CurrentPage != 1) {
					$this->_Output .= "<a href='".str_replace('{}',$this->CurrentPage-1,$this->URL)."'>$this->Prev</a>";
				} else {
					if (!$this->HideEndNextPrev) {
						$this->_Output .= $this->Prev;
					}
				}
			}
			
			// Print page links
			if ($this->Pages <= $this->LimitPages) {
				for ($Page = 1; $Page <= $this->Pages; $Page++) {
					$this->_showPage($Page);
					$this->_Output .= $this->Separator;
				}
			} else {
				$Count = $this->SkipPages;	// Show a link every few pages
				$PrevPageShown = 0;
				for ($Page = 1; $Page <= $this->Pages; $Page++) {
					// Check if we are within SkipPages/2 pages of the actual page
					if (abs($this->CurrentPage - $Page) > ($this->SkipPages/2)) {
						if (($Count++ == $this->SkipPages) || $Page == $this->Pages) {
							$this->_showSeparator($Page,$PrevPageShown);
							$this->_showPage($Page);
							$Count = 0;
							$PrevPageShown = $Page;
						}
					} else {
						$this->_showSeparator($Page,$PrevPageShown);
						$this->_showPage($Page);
						$PrevPageShown = $Page;
					}
				}
			}
			
			// Print 'Next'
			if ($this->NextPrev) {
				if ($this->CurrentPage != $this->Pages) {
					$this->_Output .= "<a href='".str_replace('{}',$this->CurrentPage+1,$this->URL)."'>$this->Next</a>";
				} else {
					if (!$this->HideEndNextPrev) {
						$this->_Output .= $this->Next;
					}
				}
			}
			$this->_Output .= $this->Footer;
			return $this->_Output;
		}
	}
	
	function _showPage($Page)
	{
		if ($Page != $this->CurrentPage) {
			$this->_Output .= "<a href='".str_replace('{}',$Page,$this->URL)."'>$Page</a>";
		} else {
			if ($this->LinkCurrentPage) {
				$this->_Output .= "<a href='".str_replace('{}',$Page,$this->URL)."' class='pageindex-current'>$Page</a>";
			} else {
				$this->_Output .= "<span class='pageindex-current'>$Page</span>";
			}
		}
	}
	
	function _showSeparator($Page,$PrevPageShown)
	{
		if ($Page > $PrevPageShown+1) {
			$this->_Output .= '..';
		} else {
			if ($Page > 1) $this->_Output .= $this->Separator;
		}
	}
}
