<?php

// XLang.class.php - Language helper class
//
// $Id: XLang.class.php 1424 2008-12-29 16:09:36Z tim $
//
// (c)2001-2008 Tim Jackson (tim@timj.co.uk)
//
// This library is free software; you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public
// License as published by the Free Software Foundation; either
// version 2.1 of the License, or (at your option) any later version.
//
// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.
// 
// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

/**
 * If you want to use this class you will need to define the following consts:
 * XLANG_BASEDIR = path to root of language files
 * XLANG_COOKIE_NAME = name to use for language selection cookie 
 * XLANG_DEFAULT_LANGUAGE = default language code
 */
class XLang {
	
	var $code = '';
	var $languages = '';					// Create a derived class and fill this
	var $languages_mappings = '';		// Create a derived class and fill this

	function XLang ($file, $setlang='') {
		global $HTTP_COOKIE_VARS;
		if (!empty($setlang)) {								// they have explicitly chosen a language
			setcookie(XLANG_COOKIE_NAME,$setlang);				// set the cookie
			$this->code = $setlang;					// and use the value they asked for (craziness checked in sanity later)
		} else {
			if ($HTTP_COOKIE_VARS[XLANG_COOKIE_NAME]) {								// if language set in cookie
				$this->code = $HTTP_COOKIE_VARS[XLANG_COOKIE_NAME];																							
			} else {
				$this->code = $this->RFC3066PreferredLanguage();		// then try to get preferred language from browser prefs
					// if none match, sanity check will catch
			}
		}
		$this->LanguageSanityCheck();			// sanity check before using language
		
		header("Content-Language: $this->code");
		
		include_once(XLANG_BASEDIR."lang-sitewide_$this->code.php");
		if ($file) {
			include_once(XLANG_BASEDIR.$file."_$this->code.php");
		}
	}


	function LanguageSanityCheck () {
		$langfound = false;
		foreach ($this->languages as $code => $name) {
			if ($code == $this->code) $langfound = true;
		}	
		
		if (!$langfound) $this->code = XLANG_DEFAULT_LANGUAGE;
	}

	function RFC3066PreferredLanguage () {
		//$HTTP_ACCEPT_LANGUAGE="DA;q=0.4, il-xy;q=0.7, jp, no;q=0.3, en;q=0.3";
	
		$chosen_langs = explode(",",$_SERVER['HTTP_ACCEPT_LANGUAGE']);
		foreach ($chosen_langs as $lang) {
			ereg("([[:alpha:]]+)-*[[:alpha:]]*(;q=(.*))*", $lang, $output);
			if (!$output[3]) $output[3]="1.0";	// default qvalue is 1.0 if none explicitly given
			// language codes are case insensitive so convert to lower
			
			// also convert 3 letter codes to 2 letter by stripping off the last letter, this is probably wrong
			//$output[1] = strtolower(substr($output[1],0,2));	
			
			// fill array but don't overwrite previous entries with higher q (e.g. en-gb;q=1.0, no, en;q=0.5 - don't want en to get 0.5!)
			if (!$lang_list[$output[1]] || $lang_list[$output[1]] < $output[3]) $lang_list[$output[1]] = $output[3];
		}
		arsort($lang_list);	// Sort into order of preference, descending
	
		// Iterate through sorted list, checking for acceptable language
		foreach ($lang_list as $lang => $pref) {
			// Check base languages
			foreach ($this->languages as $code => $name) {
				if ($code == $lang) return $lang;	// If we find acceptable language, return it
			}
			// Check mapped languages
			foreach ($this->languages_mappings as $code => $mapto) {
				if ($code == $lang) return $mapto;	// If we find acceptable language, return it
			}
		}
		return 'undefined';	// None of the available languages match any of the user's preferences
	}
}
